@@ -4,6 +4,22 @@ use Moose;
 BEGIN { extends 'Catalyst::Controller' }
 use Perl6::Junction qw/ any /;
 
+=head1 Name
+
+Bracket::Controller::Admin - Functions for admin users.
+  
+=head1 Description
+
+Controller for admin functions:
+
+* Update player points
+* Mark the round teams go out
+* Check which wins are by a lower seed
+
+=head1 Methods
+
+=cut
+
 sub auto : Private {
     my ($self, $c) = @_;
 
@@ -44,7 +60,7 @@ sub update_player_points : Global {
             $region_score->update;
         }
     }
-    $c->stash->{players} = \@players;
+    $c->stash->{players}    = \@players;
     $c->flash->{status_msg} = 'Scores Updated';
     $c->response->redirect($c->uri_for($c->controller('Player')->action_for('all')));
     return;
@@ -97,5 +113,59 @@ sub qa : Global {
     $c->stash->{template}     = 'admin/lower_seeds.tt';
 }
 
+sub update_points : Global {
+    my ($self, $c) = @_;
+    my @points = $c->model('DBIC')->update_points;
+    $c->flash->{status_msg} = 'Scores Updated';
+    $c->response->redirect($c->uri_for($c->controller('Player')->action_for('all')));
+    return;
+}
+
+=head2 round_out
+
+Mark the round teams go out.
+
+=cut
+
+sub round_out : Global : ActionClass('REST') {
+    my ($self, $c) = @_;
+
+    $c->stash->{template} = 'admin/round_out.tt';
+    my @teams = $c->model('DBIC::Team')->all;
+    $c->stash(teams => \@teams);
+}
+
+sub round_out_GET {}
+
+sub round_out_POST {
+    my  ($self, $c) = @_;
+    
+    foreach my $team (@{$c->stash->{teams}}) {
+        $team->update({ round_out => $c->request->body_parameters->{$team->id} });
+    }
+}
+
+=head2 round_out_unmarked
+
+Show only the teams that havent' been marked out yet.
+
+=cut
+
+sub round_out_unmarked : Global : ActionClass('REST') {
+    my ($self, $c) = @_;
+    $c->stash->{template} = 'admin/round_out_unmarked.tt';
+    my @teams = $c->model('DBIC::Team')->search({round_out => 7})->all;
+    $c->stash(teams => \@teams);
+}
+sub round_out_unmarked_GET {}
+
+sub round_out_unmarked_POST {
+    my  ($self, $c) = @_;
+    
+    foreach my $team (@{$c->stash->{teams}}) {
+        $team->update({ round_out => $c->request->body_parameters->{$team->id} });
+    }
+}
+
 __PACKAGE__->meta->make_immutable;
 1
